﻿Imports Telerik.Windows.Controls
Imports System.Windows.Controls
Imports LightSwitchApplication
Imports Telerik.Windows.Controls.ScheduleView.ICalendar
Imports Telerik.Windows.Controls.ScheduleView
Imports System.Windows

Namespace LightSwitchApplication
	Partial Public Class RadScheduleViewControl
		Inherits UserControl

		Public _CoreAppointments As List(Of CustomAppointment)
		Public categories As List(Of ICategory)
		Public timemarkers As List(Of ITimeMarker)

		Private _Products As List(Of Product)
		Private _CurrentAppointment As CustomAppointment

		Private Sub xScheduleView_Loaded(sender As Object, e As RoutedEventArgs) Handles xScheduleView.Loaded
			_CoreAppointments = New List(Of CustomAppointment)()

			categories = New List(Of ICategory)()

			_Products = New List(Of Product)()

			For Each icat As ICategory In xScheduleView.CategoriesSource
				categories.Add(icat)
			Next

			timemarkers = New List(Of ITimeMarker)()

			For Each marker As ITimeMarker In xScheduleView.TimeMarkersSource
				timemarkers.Add(marker)
			Next

			Dim objDataContext = DirectCast(Me.DataContext, IContentItem)

			Dim Screen = DirectCast(objDataContext.Screen, Microsoft.LightSwitch.Client.IScreenObject)

			Screen.Details.Dispatcher.BeginInvoke(
			 Sub()
				 Dim pr = TryCast(Screen, EditableScheduleViewApptsGrid).Products.ToList()
				 Me._Products.AddRange(pr)
			 End Sub)
		End Sub

		Private Sub cmbProducts_Loaded(sender As System.Object, e As System.Windows.RoutedEventArgs)
			Dim combo = DirectCast(sender, RadComboBox)
			combo.Items.AddRange(Me._Products)
			If (Me._CurrentAppointment IsNot Nothing) Then
				combo.SelectedItem = Me._CurrentAppointment.Product
				Me._CurrentAppointment = Nothing

			End If
		End Sub

		Public Sub GetLSAppointments(svAppts As List(Of ScheduleViewAppt))
			For Each sva As ScheduleViewAppt In svAppts
				Dim appt As CustomAppointment = MakeAppointment(sva)

				Me._CoreAppointments.Add(appt)
			Next

			Dispatcher.BeginInvoke(
			 Sub()
				 xScheduleView.AppointmentsSource = _CoreAppointments
			 End Sub)

		End Sub

		Private Function MakeAppointment(sva As ScheduleViewAppt) As CustomAppointment
			Dim appt As New CustomAppointment()

			appt.Subject = sva.Subject
			appt.UniqueId = sva.ApptGuid
			appt.Start = sva.StartTime
			appt.End = sva.EndTime
			appt.Body = sva.Description
			appt.IsAllDayEvent = Convert.ToBoolean(sva.IsAllDay)
			appt.Location = sva.Location
			appt.Url = sva.URL
			appt.Product = sva.Product

			If sva.Category IsNot Nothing Then
				appt.Category = categories.Where(Function(x) x.CategoryName = sva.Category).SingleOrDefault()
			End If

			If sva.Importance IsNot Nothing Then
				appt.Importance = DirectCast([Enum].Parse(GetType(Importance), sva.Importance, True), Importance)
			End If

			If sva.TimeMarker IsNot Nothing Then
				appt.TimeMarker = timemarkers.Where(Function(x) x.TimeMarkerName = sva.TimeMarker).SingleOrDefault()
			End If

			If sva.RecurrenceRule IsNot Nothing Then
				Dim pattern As New RecurrencePattern()
				RecurrencePatternHelper.TryParseRecurrencePattern(sva.RecurrenceRule, pattern)
				appt.RecurrenceRule = New RecurrenceRule(pattern)
			End If

			Return appt
		End Function

		Private Sub UpdateAppointment(sva As ScheduleViewAppt, appt As CustomAppointment)
			sva.Subject = appt.Subject
			sva.ApptGuid = appt.UniqueId
			sva.StartTime = appt.Start
			sva.EndTime = appt.End
			sva.Description = appt.Body
			sva.IsAllDay = appt.IsAllDayEvent
			sva.Location = appt.Location
			sva.URL = appt.Url
			sva.Product = appt.Product

			If appt.Category IsNot Nothing Then
				sva.Category = appt.Category.CategoryName
			End If

			If appt.TimeMarker IsNot Nothing Then
				sva.TimeMarker = appt.TimeMarker.TimeMarkerName
			End If

			If appt.RecurrenceRule IsNot Nothing Then
				sva.RecurrenceRule = RecurrencePatternHelper.RecurrencePatternToString(appt.RecurrenceRule.Pattern)
			End If
		End Sub

		Private Sub xScheduleView_AppointmentCreated(sender As System.Object, e As Telerik.Windows.Controls.AppointmentCreatedEventArgs)
			Dim objDataContext = DirectCast(Me.DataContext, IContentItem)

			Dim Screen = DirectCast(objDataContext.Screen, Microsoft.LightSwitch.Client.IScreenObject)

			Screen.Details.Dispatcher.BeginInvoke(
			Sub()
				Dim sva As ScheduleViewAppt
				sva = TryCast(Screen, EditableScheduleViewApptsGrid).ScheduleViewAppts.AddNew()
				Dim appt As Appointment = e.CreatedAppointment
				UpdateAppointment(sva, appt)
			End Sub)
		End Sub

		Private Sub xScheduleView_AppointmentDeleted(sender As System.Object, e As Telerik.Windows.Controls.AppointmentDeletedEventArgs)
			Dim objDataContext = DirectCast(Me.DataContext, IContentItem)

			Dim Screen = DirectCast(objDataContext.Screen, Microsoft.LightSwitch.Client.IScreenObject)

			Screen.Details.Dispatcher.BeginInvoke(
			 Sub()
				 Dim appt As Appointment = TryCast(e.Appointment, Appointment)

				 Dim sva As ScheduleViewAppt = TryCast(Screen, EditableScheduleViewApptsGrid).ScheduleViewAppts.Where(Function(x) x.ApptGuid = appt.UniqueId).SingleOrDefault()

				 If sva IsNot Nothing Then
					 sva.Delete()
				 End If
			 End Sub)
		End Sub

		Private Sub xScheduleView_AppointmentEdited(sender As System.Object, e As Telerik.Windows.Controls.AppointmentEditedEventArgs)
			Dim objDataContext = DirectCast(Me.DataContext, IContentItem)

			Dim Screen = DirectCast(objDataContext.Screen, Microsoft.LightSwitch.Client.IScreenObject)

			Screen.Details.Dispatcher.BeginInvoke(
			 Sub()
				 Dim appt As CustomAppointment = TryCast(e.Appointment, CustomAppointment)

				 Dim sva As ScheduleViewAppt = TryCast(Screen, EditableScheduleViewApptsGrid).ScheduleViewAppts.Where(Function(x) x.ApptGuid = appt.UniqueId).SingleOrDefault()

				 If sva IsNot Nothing Then
					 UpdateAppointment(sva, appt)
				 End If
			 End Sub)
		End Sub

		Private Sub xScheduleView_AppointmentEditing(sender As System.Object, e As Telerik.Windows.Controls.AppointmentEditingEventArgs)
			Me._CurrentAppointment = DirectCast(e.Appointment, CustomAppointment)
		End Sub
	End Class
End Namespace

